extract_local_refs

Function extract_local_refs 

fn extract_local_refs(md: &str) -> Vec<String>
Extract URLs of locally-referenced files from a Markdown document.

Returns relative paths that are referenced as images or links and that do not look like remote URLs (no :// scheme) or bare fragment anchors (starting with #).